close all
clc
clear
format compact
display('running Mars_Earth.m')
%these scripts perform calculations required for these links
run distances
run modulation

%consts
c = 299792458; %m/s
d_earth_ant = 34; %m
Tsys = 20; %K
k = 1.39e-23; %J/K Boltzmann's constant

%downlink calcs-----------------------------------------------------------
display('These are the downlink calculations')

freq = 32e9; %hz
lambda = c/freq; %m
Q = 50; %terminals on Mars that will be communicating

% a range of EIRP to determine best to achieve specific BER
EIRPsat = [60:0.5:70];

eff_e_ant = .94;
G_earth_ant = 10*log10(eff_e_ant*(4*pi^2*(d_earth_ant/2)^2)/(lambda^2))

Pr_earth = EIRPsat + G_earth_ant -20*log10(4*pi/lambda*dist_MtoE);

Pn = 10*log10((k*Tsys*BW) + (10.^(Pr_earth./10)*(Q-1)));

%account for processing gain in CDMA
SNR_despread = Pr_earth-Pn + procgain;

%accounting for turbo coding gain, get 10 dB of coding gain for turbo code
%as seenin the figure in the book
%as determined by HW 6
SNR_uncoded = SNR_despread+coding_gain;

x = sqrt(2*10.^(SNR_uncoded./10));

BER_downlink = 1/2*erfc(x/sqrt(2));

semilogy(EIRPsat, BER_downlink);
title('EIRP of Satellite vs BER')
xlabel('EIRP of Satellite(dBW)');
ylabel('BER');
grid on

indexBER = find(BER_downlink <1e-6, 1, 'first');
EIRPsat = EIRPsat(indexBER)

%determining the satellite power and gain that will satisfy the BER
Pt_sat = 100 %W
G_sat_ant = EIRPsat - 10*log10(Pt_sat) %dB

eff_sat_ant = .8;
r_sat_ant = ((((10^(G_sat_ant/10))/eff_sat_ant)*(lambda^2))/(4*pi^2))^(1/2)
beamwidth = sqrt(30000/10^(G_sat_ant/10))
%beamwidth might get too small, check and see if OK with ablity to point at
%earth Given geometry can determine radius that beam will fall onto earth
beamwidth_radius_on_earth = tand(beamwidth/2)*dist_MtoE/1e3 %km

BER_downlink = BER_downlink(indexBER)
SNR_uncoded = SNR_uncoded(indexBER)

%uplink calcs ------------------------------------------------------------
display(' ');
display('These are the uplink calculations');
frequp = 34.5e9; %Hz
lambdaup = c/frequp;

G_earth_ant_up = 10*log10(eff_e_ant*(4*pi^2*(d_earth_ant/2)^2)/(lambdaup^2))
Pt_earth = 500000; %W
EIRPearth = 10*log10(Pt_earth)+G_earth_ant_up %dBW

G_sat_ant_up = 10*log10(eff_sat_ant*(4*pi^2*(r_sat_ant)^2)/(lambdaup^2))

Pr_sat = EIRPearth + G_sat_ant_up -20*log10(4*pi/lambdaup*dist_MtoE);

Pn = 10*log10((k*Tsys*BW) + 10^(Pr_sat/10)*(Q-1));

SNR_spread_up = Pr_sat - Pn;

SNR_despread_up = SNR_spread_up + procgain;

SNR_uncoded_up = SNR_despread_up+coding_gain

x = sqrt(2*10^(SNR_uncoded_up/10));

BER_uplink = 1/2*erfc(x/sqrt(2))